#
# spec file for package python-django-mailman3
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global django_min_version           4.2
%global django_max_version           5.1
%global mailmanclient_min_version    3.3.3
%global django_allauth_min_version   0.63
%global django_gravatar2_min_version 1.0.6

%{?sle15_python_module_pythons}
%define modname django_mailman3
Name:           python-django-mailman3
Version:        1.3.14
Release:        1.3
Summary:        Django library to help interaction with Mailman
License:        GPL-3.0-only
URL:            https://gitlab.com/mailman/django-mailman3
Source0:        %{url}/-/releases/v%{version}/downloads/%{modname}-%{version}.tar.gz
Source1:        %{url}/-/releases/v%{version}/downloads/%{modname}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source3:        %{url}/-/raw/v%{version}/pytest.ini
BuildRequires:  %{python_module pdm}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-django-allauth >= %{django_allauth_min_version}
Requires:       python-django-gravatar2 >= %{django_gravatar2_min_version}
Requires:       python-mailmanclient >= %{mailmanclient_min_version}
Requires:       (python-Django >= %{django_min_version} with python-Django < %{django_max_version})
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= %{django_min_version}}
BuildRequires:  %{python_module django-allauth >= %{django_allauth_min_version}}
BuildRequires:  %{python_module django-gravatar2 >= %{django_gravatar2_min_version}}
BuildRequires:  %{python_module editables}
BuildRequires:  %{python_module mailmanclient >= %{mailmanclient_min_version}}
BuildRequires:  %{python_module pdm-backend}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Django library to help interaction with Mailman.

%prep
%autosetup -p1 -n %{modname}-%{version}

cp %{SOURCE3} pytest.ini

%build
%pyproject_wheel

%install
%pyproject_install

%{python_expand # remove for each python flavor
rm -f %{buildroot}%{$python_sitelib}/COPYING.txt
rm -f %{buildroot}%{$python_sitelib}/README.rst
rm -f %{buildroot}%{$python_sitelib}/pytest.ini
rm -f %{buildroot}%{$python_sitelib}/tox.ini
}

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH="$(pwd)"
%pytest django_mailman3

%files %{python_files}
%doc README.rst
%license COPYING.txt
%{python_sitelib}/%{modname}-%{version}.dist-info
%{python_sitelib}/%{modname}

%changelog
* Tue Jul  2 2024 Markéta Machová <mmachova@suse.com>
- Re-download pytest.ini and fix multiflavor packaging
* Sun Jun 23 2024 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.14
  * See https://gitlab.com/mailman/django-mailman3/-/blob/v1.3.14/README.rst
    or the packaged README.rst.
* Sun Jun 23 2024 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.13
  * See https://gitlab.com/mailman/django-mailman3/-/blob/v1.3.13/README.rst
    or the packaged README.rst.
* Tue Apr 23 2024 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.12
  * See https://gitlab.com/mailman/django-mailman3/-/blob/v1.3.12/README.rst
    or README.rst packaged in this file.
- Added pytest.ini
* Thu Feb 29 2024 Ben Greiner <code@bnavigator.de>
- Build PEP517 wheel
* Mon Nov  6 2023 Marcus Rueckert <mrueckert@suse.de>
- make it easier to notice to keep buildrequires and runtime
  requires version limits in sync. This will also help us to notice
  early when the version of other libraries do not match the
  requires encoded in the source code.
* Thu Nov  2 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.11
  * See https://gitlab.com/mailman/django-mailman3/-/blob/master/README.rst
    or README.rst packaged in this file.
  * BREAKING CHANGE: django_mailman3 now requires django_allauth>=0.56. This
    requires the addition of allauth.account.middleware.AccountMiddleware to
    MIDDLEWARE in your Django settings. If your installation uses settings from
    mailman-web as here, upgrading mailman-web to 0.0.7 will do this.
* Sun Jun 25 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.9
  * Add support for Python 3.11
- Use sle15_python_module_pythons
* Mon Nov 21 2022 Andreas Schneider <asn@cryptomilk.org>
- Fix running the tests on openSUSE Leap 15.4
* Thu Nov 17 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.8
  * Add support for Django 4.0 and 4.1 (Fixes #55)
  * Add support for Python 3.10 (See !153)
  * Fix the Fedora socialaccount provider. (Fixes #50)
  * Add pagination only when there are more than one pages. (Fixes #58)
  * Use Pytest as the test runner.
- Removed dj40.patch
- Removed dj41.patch
* Wed Oct  5 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add dj41.patch to make it compatible with django 4.1 based on
  https://gitlab.com/mailman/django-mailman3/-/merge_requests/170
* Thu Jul 14 2022 Jacob Michalskie <hel@lcp.world>
- Fix the patch for django 4.0 to update dependencies
* Mon Jul  4 2022 Ben Greiner <code@bnavigator.de>
- Enable multiflavor so that we can pin mailman3 and hyperkitty
  to python39
* Mon May  9 2022 Matej Cepl <mcepl@suse.com>
- Clean up the SPEC file.
* Mon May  9 2022 pgajdos@suse.com
- python-mock is not required for build
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Add dj40.patch for Django 4.0 compatibility
* Wed Nov 17 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.7
  * Set the minimum required version of mailmanclient in setup.py.
* Tue May  4 2021 Ben Greiner <code@bnavigator.de>
- restrict to primary python3 flavor due to mailman
* Wed Feb  3 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.5
  * Add a new method get_django_user to return Django User model. (See !99)
  * Add delete_archives field to mailinglist_deleted Signal.
  * Replaced deprecated ugettexy_lazy with gettext_lazy. (Closes #37)
- Fix building on tumbleweed
* Tue Aug  4 2020 Stasiek Michalski <stasiek@michalski.cc>
- Update to 1.3.4
  * Fix a bug caused by bumping to Mailman API 3.1 in version 1.3.3 which
    resulted in 404 errors for some users.
* Wed May 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.3.3rc1
  * Update a user's preferred_address in Mailman Core when a user
    updates their primary address in Profile.
  * Do not exit with --code-zero.
  * more bugfixes
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Tue Nov 26 2019 pgajdos@suse.com
- run the testsuite
* Wed Oct  2 2019 pgajdos@suse.com
- initial version 1.3.0, required by HyperKitty [SLE-7686]
